@@ -17,9 +17,7 @@
 package kafka.security.auth
 
 import kafka.common.KafkaException
-import org.apache.kafka.common.acl.AclPermissionType
-import org.junit.Assert.assertEquals
-import org.junit.Test
+import org.junit.{Test, Assert}
 import org.scalatest.junit.JUnitSuite
 
 class PermissionTypeTest extends JUnitSuite {
@@ -27,28 +25,14 @@ class PermissionTypeTest extends JUnitSuite {
   @Test
   def testFromString(): Unit = {
     val permissionType = PermissionType.fromString("Allow")
-    assertEquals(Allow, permissionType)
+    Assert.assertEquals(Allow, permissionType)
 
     try {
       PermissionType.fromString("badName")
       fail("Expected exception on invalid PermissionType name.")
     } catch {
-      case _: KafkaException => // expected
+      case e: KafkaException => // expected
     }
   }
 
-  /**
-    * Test round trip conversions between org.apache.kafka.common.acl.AclPermissionType and
-    * kafka.security.auth.PermissionType.
-    */
-  @Test
-  def testJavaConversions(): Unit = {
-    AclPermissionType.values().foreach {
-      case AclPermissionType.UNKNOWN | AclPermissionType.ANY =>
-      case aclPerm =>
-        val perm = PermissionType.fromJava(aclPerm)
-        val aclPerm2 = perm.toJava
-        assertEquals(aclPerm, aclPerm2)
-    }
-  }
 }
