@@ -20,18 +20,18 @@ package kafka.tools
 import java.util
 import java.util.concurrent.atomic.{AtomicBoolean, AtomicInteger}
 import java.util.concurrent.{CountDownLatch, TimeUnit}
-import java.util.regex.Pattern
+import java.util.regex.{PatternSyntaxException, Pattern}
 import java.util.{Collections, Properties}
 
 import com.yammer.metrics.core.Gauge
 import joptsimple.OptionParser
-import kafka.consumer.{BaseConsumer, BaseConsumerRecord, Blacklist, ConsumerIterator, ConsumerThreadId, ConsumerTimeoutException, TopicFilter, Whitelist, ZookeeperConsumerConnector, ConsumerConfig => OldConsumerConfig}
+import kafka.consumer.{BaseConsumerRecord, ConsumerIterator, BaseConsumer, Blacklist, ConsumerConfig, ConsumerThreadId, ConsumerTimeoutException, TopicFilter, Whitelist, ZookeeperConsumerConnector}
 import kafka.javaapi.consumer.ConsumerRebalanceListener
 import kafka.metrics.KafkaMetricsGroup
 import kafka.serializer.DefaultDecoder
-import kafka.utils.{CommandLineUtils, CoreUtils, Logging, ZKConfig}
+import kafka.utils.{CommandLineUtils, CoreUtils, Logging}
 import org.apache.kafka.clients.consumer
-import org.apache.kafka.clients.consumer.{CommitFailedException, Consumer, ConsumerRecord, KafkaConsumer, OffsetAndMetadata}
+import org.apache.kafka.clients.consumer.{OffsetAndMetadata, Consumer, ConsumerRecord, KafkaConsumer, CommitFailedException}
 import org.apache.kafka.clients.producer.internals.ErrorLoggingCallback
 import org.apache.kafka.clients.producer.{KafkaProducer, ProducerConfig, ProducerRecord, RecordMetadata}
 import org.apache.kafka.common.TopicPartition
@@ -39,12 +39,9 @@ import org.apache.kafka.common.serialization.ByteArrayDeserializer
 import org.apache.kafka.common.utils.Utils
 import org.apache.kafka.common.errors.WakeupException
 
-import scala.collection.JavaConverters._
+import scala.collection.JavaConversions._
 import scala.collection.mutable.HashMap
 import scala.util.control.ControlThrowable
-import org.apache.kafka.clients.consumer.{ConsumerConfig => NewConsumerConfig}
-import org.apache.kafka.common.header.internals.RecordHeaders
-import org.apache.kafka.common.record.RecordBatch
 
 /**
  * The mirror maker has the following architecture:
@@ -59,15 +56,15 @@ import org.apache.kafka.common.record.RecordBatch
  *            max.block.ms=max long
  *            max.in.flight.requests.per.connection=1
  *       2. Consumer Settings
- *            enable.auto.commit=false
+ *            auto.commit.enable=false
  *       3. Mirror Maker Setting:
  *            abort.on.send.failure=true
  */
 object MirrorMaker extends Logging with KafkaMetricsGroup {
 
-  private[tools] var producer: MirrorMakerProducer = null
+  private var producer: MirrorMakerProducer = null
   private var mirrorMakerThreads: Seq[MirrorMakerThread] = null
-  private val isShuttingDown: AtomicBoolean = new AtomicBoolean(false)
+  private val isShuttingdown: AtomicBoolean = new AtomicBoolean(false)
   // Track the messages not successfully sent by mirror maker.
   private val numDroppedMessages: AtomicInteger = new AtomicInteger(0)
   private var messageHandler: MirrorMakerMessageHandler = null
@@ -87,7 +84,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
 
     info("Starting mirror maker")
     try {
-      val parser = new OptionParser(false)
+      val parser = new OptionParser
 
       val consumerConfigOpt = parser.accepts("consumer.config",
         "Embedded consumer config for consuming from the source cluster.")
@@ -96,7 +93,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
         .ofType(classOf[String])
 
       val useNewConsumerOpt = parser.accepts("new.consumer",
-        "Use new consumer in mirror maker (this is the default).")
+        "Use new consumer in mirror maker.")
 
       val producerConfigOpt = parser.accepts("producer.config",
         "Embedded producer config.")
@@ -124,7 +121,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
         .ofType(classOf[String])
 
       val offsetCommitIntervalMsOpt = parser.accepts("offset.commit.interval.ms",
-        "Offset commit interval in ms.")
+        "Offset commit interval in ms")
         .withRequiredArg()
         .describedAs("offset commit interval in millisecond")
         .ofType(classOf[java.lang.Integer])
@@ -137,7 +134,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
         .ofType(classOf[String])
 
       val rebalanceListenerArgsOpt = parser.accepts("rebalance.listener.args",
-        "Arguments used by custom rebalance listener for mirror maker consumer.")
+        "Arguments used by custom rebalance listener for mirror maker consumer")
         .withRequiredArg()
         .describedAs("Arguments passed to custom rebalance listener constructor as a string.")
         .ofType(classOf[String])
@@ -171,47 +168,26 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
 
       if (options.has(helpOpt)) {
         parser.printHelpOn(System.out)
-        sys.exit(0)
+        System.exit(0)
       }
 
       CommandLineUtils.checkRequiredArgs(parser, options, consumerConfigOpt, producerConfigOpt)
 
-      val consumerProps = Utils.loadProps(options.valueOf(consumerConfigOpt))
-      val useOldConsumer = consumerProps.containsKey(ZKConfig.ZkConnectProp)
-
-      if (useOldConsumer) {
-        if (options.has(useNewConsumerOpt)) {
-          error(s"The consumer configuration parameter `${ZKConfig.ZkConnectProp}` is not valid when using --new.consumer")
-          sys.exit(1)
-        }
-
-        if (consumerProps.containsKey(NewConsumerConfig.BOOTSTRAP_SERVERS_CONFIG)) {
-          error(s"The configuration parameters `${ZKConfig.ZkConnectProp}` (old consumer) and " +
-            s"`${NewConsumerConfig.BOOTSTRAP_SERVERS_CONFIG}` (new consumer) cannot be used together.")
-          sys.exit(1)
-        }
-
-        if (List(whitelistOpt, blacklistOpt).count(options.has) != 1) {
-          error("Exactly one of whitelist or blacklist is required.")
-          sys.exit(1)
-        }
-      } else {
+      val useNewConsumer = options.has(useNewConsumerOpt)
+      if (useNewConsumer) {
         if (options.has(blacklistOpt)) {
           error("blacklist can not be used when using new consumer in mirror maker. Use whitelist instead.")
-          sys.exit(1)
+          System.exit(1)
         }
-
         if (!options.has(whitelistOpt)) {
           error("whitelist must be specified when using new consumer in mirror maker.")
-          sys.exit(1)
+          System.exit(1)
+        }
+      } else {
+        if (List(whitelistOpt, blacklistOpt).count(options.has) != 1) {
+          error("Exactly one of whitelist or blacklist is required.")
+          System.exit(1)
         }
-
-        if (!consumerProps.containsKey(NewConsumerConfig.PARTITION_ASSIGNMENT_STRATEGY_CONFIG))
-          System.err.println("WARNING: The default partition assignment strategy of the new-consumer-based mirror maker will " +
-            "change from 'range' to 'roundrobin' in an upcoming release (so that better load balancing can be achieved). If " +
-            "you prefer to make this switch in advance of that release add the following to the corresponding new-consumer " +
-            "config: 'partition.assignment.strategy=org.apache.kafka.clients.consumer.RoundRobinAssignor'")
-
       }
 
       abortOnSendFailure = options.valueOf(abortOnSendFailureOpt).toBoolean
@@ -226,8 +202,6 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
 
       // create producer
       val producerProps = Utils.loadProps(options.valueOf(producerConfigOpt))
-      val sync = producerProps.getProperty("producer.type", "async").equals("sync")
-      producerProps.remove("producer.type")
       // Defaults to no data loss settings.
       maybeSetDefaultProperty(producerProps, ProducerConfig.RETRIES_CONFIG, Int.MaxValue.toString)
       maybeSetDefaultProperty(producerProps, ProducerConfig.MAX_BLOCK_MS_CONFIG, Long.MaxValue.toString)
@@ -236,11 +210,11 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
       // Always set producer key and value serializer to ByteArraySerializer.
       producerProps.setProperty(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.ByteArraySerializer")
       producerProps.setProperty(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, "org.apache.kafka.common.serialization.ByteArraySerializer")
-      producer = new MirrorMakerProducer(sync, producerProps)
+      producer = new MirrorMakerProducer(producerProps)
 
       // Create consumers
-      val mirrorMakerConsumers = if (useOldConsumer) {
-        val customRebalanceListener: Option[ConsumerRebalanceListener] = {
+      val mirrorMakerConsumers = if (!useNewConsumer) {
+        val customRebalanceListener = {
           val customRebalanceListenerClass = options.valueOf(consumerRebalanceListenerOpt)
           if (customRebalanceListenerClass != null) {
             val rebalanceListenerArgs = options.valueOf(rebalanceListenerArgsOpt)
@@ -253,14 +227,17 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
             None
           }
         }
+
+        if (customRebalanceListener.exists(!_.isInstanceOf[ConsumerRebalanceListener]))
+          throw new IllegalArgumentException("The rebalance listener should be an instance of kafka.consumer.ConsumerRebalanceListener")
         createOldConsumers(
           numStreams,
-          consumerProps,
+          options.valueOf(consumerConfigOpt),
           customRebalanceListener,
           Option(options.valueOf(whitelistOpt)),
           Option(options.valueOf(blacklistOpt)))
       } else {
-        val customRebalanceListener: Option[org.apache.kafka.clients.consumer.ConsumerRebalanceListener] = {
+        val customRebalanceListener = {
           val customRebalanceListenerClass = options.valueOf(consumerRebalanceListenerOpt)
           if (customRebalanceListenerClass != null) {
             val rebalanceListenerArgs = options.valueOf(rebalanceListenerArgsOpt)
@@ -273,9 +250,12 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
             None
           }
         }
+        if (customRebalanceListener.exists(!_.isInstanceOf[org.apache.kafka.clients.consumer.ConsumerRebalanceListener]))
+          throw new IllegalArgumentException("The rebalance listener should be an instance of" +
+            "org.apache.kafka.clients.consumer.ConsumerRebalanceListner")
         createNewConsumers(
           numStreams,
-          consumerProps,
+          options.valueOf(consumerConfigOpt),
           customRebalanceListener,
           Option(options.valueOf(whitelistOpt)))
       }
@@ -308,10 +288,12 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
   }
 
   private def createOldConsumers(numStreams: Int,
-                                 consumerConfigProps: Properties,
-                                 customRebalanceListener: Option[ConsumerRebalanceListener],
-                                 whitelist: Option[String],
-                                 blacklist: Option[String]) : Seq[MirrorMakerBaseConsumer] = {
+                                consumerConfigPath: String,
+                                customRebalanceListener: Option[ConsumerRebalanceListener],
+                                whitelist: Option[String],
+                                blacklist: Option[String]) : Seq[MirrorMakerBaseConsumer] = {
+    // Create consumer connector
+    val consumerConfigProps = Utils.loadProps(consumerConfigPath)
     // Disable consumer auto offsets commit to prevent data loss.
     maybeSetDefaultProperty(consumerConfigProps, "auto.commit.enable", "false")
     // Set the consumer timeout so we will not block for low volume pipeline. The timeout is necessary to make sure
@@ -321,7 +303,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     val groupIdString = consumerConfigProps.getProperty("group.id")
     val connectors = (0 until numStreams) map { i =>
       consumerConfigProps.setProperty("client.id", groupIdString + "-" + i.toString)
-      val consumerConfig = new OldConsumerConfig(consumerConfigProps)
+      val consumerConfig = new ConsumerConfig(consumerConfigProps)
       new ZookeeperConsumerConnector(consumerConfig)
     }
 
@@ -341,9 +323,11 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
   }
 
   def createNewConsumers(numStreams: Int,
-                         consumerConfigProps: Properties,
+                         consumerConfigPath: String,
                          customRebalanceListener: Option[org.apache.kafka.clients.consumer.ConsumerRebalanceListener],
                          whitelist: Option[String]) : Seq[MirrorMakerBaseConsumer] = {
+    // Create consumer connector
+    val consumerConfigProps = Utils.loadProps(consumerConfigPath)
     // Disable consumer auto offsets commit to prevent data loss.
     maybeSetDefaultProperty(consumerConfigProps, "enable.auto.commit", "false")
     // Hardcode the deserializer to ByteArrayDeserializer
@@ -372,7 +356,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
           mirrorMakerConsumer.commit()
           throw e
 
-        case _: CommitFailedException =>
+        case e: CommitFailedException =>
           warn("Failed to commit offsets because the consumer group has rebalanced and assigned partitions to " +
             "another instance. If you see this regularly, it could indicate that you need to either increase " +
             s"the consumer's ${consumer.ConsumerConfig.SESSION_TIMEOUT_MS_CONFIG} or reduce the number of records " +
@@ -384,7 +368,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
   }
 
   def cleanShutdown() {
-    if (isShuttingDown.compareAndSet(false, true)) {
+    if (isShuttingdown.compareAndSet(false, true)) {
       info("Start clean shutdown.")
       // Shutdown consumer threads.
       info("Shutting down consumer threads.")
@@ -426,59 +410,51 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
           try {
             while (!exitingOnSendFailure && !shuttingDown && mirrorMakerConsumer.hasData) {
               val data = mirrorMakerConsumer.receive()
-              if (data.value != null) {
-                trace("Sending message with value size %d and offset %d.".format(data.value.length, data.offset))
-              } else {
-                trace("Sending message with null value and offset %d.".format(data.offset))
-              }
+              trace("Sending message with value size %d and offset %d".format(data.value.length, data.offset))
               val records = messageHandler.handle(data)
-              records.asScala.foreach(producer.send)
+              records.foreach(producer.send)
               maybeFlushAndCommitOffsets()
             }
           } catch {
-            case _: ConsumerTimeoutException =>
+            case cte: ConsumerTimeoutException =>
               trace("Caught ConsumerTimeoutException, continue iteration.")
-            case _: WakeupException =>
+            case we: WakeupException =>
               trace("Caught ConsumerWakeupException, continue iteration.")
           }
           maybeFlushAndCommitOffsets()
         }
       } catch {
         case t: Throwable =>
-          exitingOnSendFailure = true
           fatal("Mirror maker thread failure due to ", t)
       } finally {
-        CoreUtils.swallow ({
+        CoreUtils.swallow {
           info("Flushing producer.")
           producer.flush()
 
           // note that this commit is skipped if flush() fails which ensures that we don't lose messages
           info("Committing consumer offsets.")
           commitOffsets(mirrorMakerConsumer)
-        }, this)
+        }
 
         info("Shutting down consumer connectors.")
-        CoreUtils.swallow(mirrorMakerConsumer.stop(), this)
-        CoreUtils.swallow(mirrorMakerConsumer.cleanup(), this)
+        CoreUtils.swallow(mirrorMakerConsumer.stop())
+        CoreUtils.swallow(mirrorMakerConsumer.cleanup())
         shutdownLatch.countDown()
         info("Mirror maker thread stopped")
         // if it exits accidentally, stop the entire mirror maker
-        if (!isShuttingDown.get()) {
+        if (!isShuttingdown.get()) {
           fatal("Mirror maker thread exited abnormally, stopping the whole mirror maker.")
-          sys.exit(-1)
+          System.exit(-1)
         }
       }
     }
 
     def maybeFlushAndCommitOffsets() {
-      val commitRequested = mirrorMakerConsumer.commitRequested()
-      if (commitRequested || System.currentTimeMillis() - lastOffsetCommitMs > offsetCommitIntervalMs) {
-        debug("Committing MirrorMaker state.")
+      if (System.currentTimeMillis() - lastOffsetCommitMs > offsetCommitIntervalMs) {
+        debug("Committing MirrorMaker state automatically.")
         producer.flush()
         commitOffsets(mirrorMakerConsumer)
         lastOffsetCommitMs = System.currentTimeMillis()
-        if (commitRequested)
-          mirrorMakerConsumer.notifyCommit()
       }
     }
 
@@ -489,7 +465,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
         mirrorMakerConsumer.stop()
       }
       catch {
-        case _: InterruptedException =>
+        case ie: InterruptedException =>
           warn("Interrupt during shutdown of the mirror maker thread")
       }
     }
@@ -499,7 +475,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
         shutdownLatch.await()
         info("Mirror maker thread shutdown complete")
       } catch {
-        case _: InterruptedException =>
+        case ie: InterruptedException =>
           warn("Shutdown of the mirror maker thread interrupted")
       }
     }
@@ -507,53 +483,21 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
 
   private[kafka] trait MirrorMakerBaseConsumer extends BaseConsumer {
     def init()
-    def commitRequested(): Boolean
-    def notifyCommit()
-    def requestAndWaitForCommit()
     def hasData : Boolean
   }
 
   private class MirrorMakerOldConsumer(connector: ZookeeperConsumerConnector,
                                        filterSpec: TopicFilter) extends MirrorMakerBaseConsumer {
     private var iter: ConsumerIterator[Array[Byte], Array[Byte]] = null
-    private var immediateCommitRequested: Boolean = false
-    private var numCommitsNotified: Long = 0
 
     override def init() {
       // Creating one stream per each connector instance
       val streams = connector.createMessageStreamsByFilter(filterSpec, 1, new DefaultDecoder(), new DefaultDecoder())
       require(streams.size == 1)
-      val stream = streams.head
+      val stream = streams(0)
       iter = stream.iterator()
     }
 
-    override def requestAndWaitForCommit() {
-      this.synchronized {
-        // only wait() if mirrorMakerConsumer has been initialized and it has not been cleaned up.
-        if (iter != null) {
-          immediateCommitRequested = true
-          val nextNumCommitsNotified = numCommitsNotified + 1
-          do {
-            this.wait()
-          } while (numCommitsNotified < nextNumCommitsNotified)
-        }
-      }
-    }
-
-    override def notifyCommit() {
-      this.synchronized {
-        immediateCommitRequested = false
-        numCommitsNotified = numCommitsNotified + 1
-        this.notifyAll()
-      }
-    }
-
-    override def commitRequested(): Boolean = {
-      this.synchronized {
-        immediateCommitRequested
-      }
-    }
-
     override def hasData = iter.hasNext()
 
     override def receive() : BaseConsumerRecord = {
@@ -564,8 +508,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
                          messageAndMetadata.timestamp,
                          messageAndMetadata.timestampType,
                          messageAndMetadata.key,
-                         messageAndMetadata.message,
-                         new RecordHeaders())
+                         messageAndMetadata.message)
     }
 
     override def stop() {
@@ -573,15 +516,6 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     }
 
     override def cleanup() {
-      // We need to set the iterator to null and notify the rebalance listener thread.
-      // This is to handle the case that the consumer rebalance is triggered when the
-      // mirror maker thread is shutting down and the rebalance listener is waiting for the offset commit.
-      this.synchronized {
-        iter = null
-        if (immediateCommitRequested) {
-          notifyCommit()
-        }
-      }
       connector.shutdown()
     }
 
@@ -590,8 +524,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     }
   }
 
-  // Only for testing
-  private[tools] class MirrorMakerNewConsumer(consumer: Consumer[Array[Byte], Array[Byte]],
+  private class MirrorMakerNewConsumer(consumer: Consumer[Array[Byte], Array[Byte]],
                                        customRebalanceListener: Option[org.apache.kafka.clients.consumer.ConsumerRebalanceListener],
                                        whitelistOpt: Option[String])
     extends MirrorMakerBaseConsumer {
@@ -606,38 +539,21 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     override def init() {
       debug("Initiating new consumer")
       val consumerRebalanceListener = new InternalRebalanceListenerForNewConsumer(this, customRebalanceListener)
-      whitelistOpt.foreach { whitelist =>
+      if (whitelistOpt.isDefined) {
         try {
-          consumer.subscribe(Pattern.compile(Whitelist(whitelist).regex), consumerRebalanceListener)
+          consumer.subscribe(Pattern.compile(whitelistOpt.get), consumerRebalanceListener)
         } catch {
-          case pse: RuntimeException =>
-            error(s"Invalid expression syntax: $whitelist")
+          case pse: PatternSyntaxException =>
+            error("Invalid expression syntax: %s".format(whitelistOpt.get))
             throw pse
         }
       }
     }
 
-    override def requestAndWaitForCommit() {
-      // Do nothing
-    }
-
-    override def notifyCommit() {
-      // Do nothing
-    }
-    
-    override def commitRequested(): Boolean = {
-      false
-    }
-
     override def hasData = true
 
     override def receive() : BaseConsumerRecord = {
       if (recordIter == null || !recordIter.hasNext) {
-        // In scenarios where data does not arrive within offsetCommitIntervalMs and
-        // offsetCommitIntervalMs is less than poll's timeout, offset commit will be delayed for any
-        // uncommitted record since last poll. Using one second as poll's timeout ensures that
-        // offsetCommitIntervalMs, of value greater than 1 second, does not see delays in offset
-        // commit.
         recordIter = consumer.poll(1000).iterator
         if (!recordIter.hasNext)
           throw new ConsumerTimeoutException
@@ -654,8 +570,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
                          record.timestamp,
                          record.timestampType,
                          record.key,
-                         record.value,
-                         record.headers)
+                         record.value)
     }
 
     override def stop() {
@@ -667,7 +582,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     }
 
     override def commit() {
-      consumer.commitSync(offsets.map { case (tp, offset) =>  (tp, new OffsetAndMetadata(offset, ""))}.asJava)
+      consumer.commitSync(offsets.map { case (tp, offset) =>  (tp, new OffsetAndMetadata(offset, ""))})
       offsets.clear()
     }
   }
@@ -692,8 +607,8 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     extends ConsumerRebalanceListener {
 
     override def beforeReleasingPartitions(partitionOwnership: java.util.Map[String, java.util.Set[java.lang.Integer]]) {
-      // The zookeeper listener thread, which executes this method, needs to wait for MirrorMakerThread to flush data and commit offset
-      mirrorMakerConsumer.requestAndWaitForCommit()
+      producer.flush()
+      commitOffsets(mirrorMakerConsumer)
       // invoke custom consumer rebalance listener
       customRebalanceListenerForOldConsumer.foreach(_.beforeReleasingPartitions(partitionOwnership))
     }
@@ -704,7 +619,9 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
     }
   }
 
-  private[tools] class MirrorMakerProducer(val sync: Boolean, val producerProps: Properties) {
+  private class MirrorMakerProducer(val producerProps: Properties) {
+
+    val sync = producerProps.getProperty("producer.type", "async").equals("sync")
 
     val producer = new KafkaProducer[Array[Byte], Array[Byte]](producerProps)
 
@@ -758,8 +675,7 @@ object MirrorMaker extends Logging with KafkaMetricsGroup {
 
   private[tools] object defaultMirrorMakerMessageHandler extends MirrorMakerMessageHandler {
     override def handle(record: BaseConsumerRecord): util.List[ProducerRecord[Array[Byte], Array[Byte]]] = {
-      val timestamp: java.lang.Long = if (record.timestamp == RecordBatch.NO_TIMESTAMP) null else record.timestamp
-      Collections.singletonList(new ProducerRecord(record.topic, null, timestamp, record.key, record.value, record.headers))
+      Collections.singletonList(new ProducerRecord[Array[Byte], Array[Byte]](record.topic, null, record.timestamp, record.key, record.value))
     }
   }
 
